@@ -3,7 +3,7 @@ package Alien::Base::ModuleBuild;
 use strict;
 use warnings;
 
-our $VERSION = '0.012';
+our $VERSION = '0.014';
 $VERSION = eval $VERSION;
 
 use parent 'Module::Build';
@@ -346,6 +346,7 @@ sub ACTION_alien_code {
   }
 
   $self->config_data( install_type => 'share' );
+  $self->config_data( original_prefix => $self->alien_library_destination );
 
   my $pc = $self->alien_load_pkgconfig;
   my $pc_version = (
@@ -439,7 +440,7 @@ sub ACTION_alien_install {
     foreach my $dir (qw( bin lib )) {
       next unless -d $dir;
       opendir(my $dh, $dir);
-      my @dlls = grep { /\.so/ || /\.(dylib|la|dll|dll\.a)$/ } grep !/^\./, readdir $dh;
+      my @dlls = grep { /\.so/ || /\.(dylib|bundle|la|dll|dll\.a)$/ } grep !/^\./, readdir $dh;
       closedir $dh;
       foreach my $dll (@dlls) {
         my $from = File::Spec->catfile($dir, $dll);
