@@ -3,10 +3,11 @@ package Alien::Base::PkgConfig;
 use strict;
 use warnings;
 
-our $VERSION = '0.012';
+our $VERSION = '0.014';
 $VERSION = eval $VERSION;
 
 use Carp;
+use Config;
 use File::Basename qw/fileparse/;
 use File::Spec;
 use Capture::Tiny qw( capture_stderr );
@@ -123,7 +124,14 @@ my $pkg_config_command;
 sub pkg_config_command {
   unless (defined $pkg_config_command) {
     capture_stderr {
-      if (`pkg-config --version` && $? == 0) {
+    
+      # For now we prefer PkgConfig.pm over pkg-config on
+      # Solaris 64 bit Perls.  We may need to do this on
+      # other platforms, in which case this logic should
+      # be abstracted so that it can be shared here and
+      # in Build.PL
+
+      if (`pkg-config --version` && $? == 0 && !($^O eq 'solaris' && $Config{ptrsize} == 8)) {
         $pkg_config_command = 'pkg-config';
       } else {
         require PkgConfig;
